==> jc-1.4.0.tar.gz: gnu/regexp/RETokenStart.h <==
// class gnu.regexp.RETokenStart

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class dd4fc3b77e06f816 gnu_regexp_RETokenStart
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenStart_H_
#define _JC_gnu_regexp_RETokenStart_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenStart$sub_refs	_jc_gnu_regexp_RETokenStart$sub_refs;
typedef struct _jc_gnu_regexp_RETokenStart$sub_nonrefs	_jc_gnu_regexp_RETokenStart$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenStart$refs	_jc_gnu_regexp_RETokenStart$refs;
typedef struct _jc_gnu_regexp_RETokenStart$nonrefs	_jc_gnu_regexp_RETokenStart$nonrefs;
typedef struct _jc_gnu_regexp_RETokenStart$object	_jc_gnu_regexp_RETokenStart$object;

typedef const struct _jc_gnu_regexp_RETokenStart$vmethods	_jc_gnu_regexp_RETokenStart$vmethods;
typedef const struct _jc_gnu_regexp_RETokenStart$vtable	_jc_gnu_regexp_RETokenStart$vtable;
typedef const struct _jc_gnu_regexp_RETokenStart$vtype	_jc_gnu_regexp_RETokenStart$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenStart$method$_init$206934d97c5ba451(_jc_env *, struct _jc_gnu_regexp_RETokenStart$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_gnu_regexp_RETokenStart$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenStart$object *, struct _jc_java_lang_StringBuffer$object *);
extern jboolean _jc_gnu_regexp_RETokenStart$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenStart$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenStart$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenStart$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenStart$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenStart$object *, struct _jc_java_lang_StringBuffer$object *);
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenStart$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
};

// Vtable
struct _jc_gnu_regexp_RETokenStart$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenStart$vmethods	gnu_regexp_RETokenStart;
};

// Vtype
struct _jc_gnu_regexp_RETokenStart$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenStart$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenStart$sub_refs {
	struct _jc_java_lang_String$object	*newline;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenStart$refs {
    _jc_gnu_regexp_RETokenStart$sub_refs	gnu_regexp_RETokenStart;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenStart$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenStart$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenStart$sub_nonrefs	gnu_regexp_RETokenStart;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenStart$object {
	_jc_gnu_regexp_RETokenStart$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenStart$vtype	*vtype;
	_jc_gnu_regexp_RETokenStart$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenStart$vtype _jc_gnu_regexp_RETokenStart$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenStart, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenStart$class_object;

#endif	/* _JC_gnu_regexp_RETokenStart_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/RETokenStart.h <==
// class gnu.regexp.RETokenStart

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class dd4fc3b77e06f816 gnu_regexp_RETokenStart
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenStart_H_
#define _JC_gnu_regexp_RETokenStart_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenStart$sub_refs	_jc_gnu_regexp_RETokenStart$sub_refs;
typedef struct _jc_gnu_regexp_RETokenStart$sub_nonrefs	_jc_gnu_regexp_RETokenStart$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenStart$refs	_jc_gnu_regexp_RETokenStart$refs;
typedef struct _jc_gnu_regexp_RETokenStart$nonrefs	_jc_gnu_regexp_RETokenStart$nonrefs;
typedef struct _jc_gnu_regexp_RETokenStart$object	_jc_gnu_regexp_RETokenStart$object;

typedef const struct _jc_gnu_regexp_RETokenStart$vmethods	_jc_gnu_regexp_RETokenStart$vmethods;
typedef const struct _jc_gnu_regexp_RETokenStart$vtable	_jc_gnu_regexp_RETokenStart$vtable;
typedef const struct _jc_gnu_regexp_RETokenStart$vtype	_jc_gnu_regexp_RETokenStart$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenStart$method$_init$206934d97c5ba451(_jc_env *, struct _jc_gnu_regexp_RETokenStart$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_regexp_RETokenStart$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenStart$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RETokenStart$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenStart$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenStart$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenStart$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenStart$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenStart$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenStart$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_RETokenStart$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenStart$vmethods	gnu_regexp_RETokenStart;
};

// Vtype
struct _jc_gnu_regexp_RETokenStart$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenStart$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenStart$sub_refs {
	struct _jc_java_lang_String$object	*newline;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenStart$refs {
    _jc_gnu_regexp_RETokenStart$sub_refs	gnu_regexp_RETokenStart;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenStart$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenStart$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenStart$sub_nonrefs	gnu_regexp_RETokenStart;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenStart$object {
	_jc_gnu_regexp_RETokenStart$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenStart$vtype	*vtype;
	_jc_gnu_regexp_RETokenStart$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenStart$vtype _jc_gnu_regexp_RETokenStart$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenStart, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenStart$class_object;

#endif	/* _JC_gnu_regexp_RETokenStart_H_ */
